| Title: | Import Multiple File Types |
|---|---|
| Description: | Functions to import multiple files of multiple data file types ('.xlsx', '.xls', '.csv', '.txt') from a given directory into R data frames. |
| Authors: | Srivenkatesh Gandhi<[email protected]>, Kreshnaa Raam S Bethusamy <[email protected]> |
| Maintainer: | Srivenkatesh Gandhi <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.3 |
| Built: | 2026-05-27 06:20:06 UTC |
| Source: | https://github.com/cran/DataLoader |
importAllMdf function loads various data file types in a selected directory to separate dataframes, and stores them as a list. Data frames can be accessed as list elements by using "listname$filename" or "listname[]".
importAllMdf(path = NULL)importAllMdf(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single list of dataframes containing all the files imported and stored as dataframes.
importAllSdf function loads various data file types in a selected directory to dataframes, combines all the data frames and stores it as a single data frame. Note that all the files to be loaded should have the same number of columns for rbind to work
importAllSdf(path = NULL)importAllSdf(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single dataframe containing all the files imported and rbinded into one.
importCsv function loads .csv file types in a selected directory to separate dataframes, and stores them as a list. Data frames can be accessed as list elements by using "listname$filename" or "listname[]".
importCsv(path = NULL)importCsv(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single list of dataframes containing all the files imported and stored as dataframes.
importCsv2 function loads .csv file types in a selected directory to separate dataframes, and stores them as a list. Data frames can be accessed as list elements by using "listname$filename" or "listname[]".
importCsv2(path = NULL)importCsv2(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single list of dataframes containing all the files imported and stored as dataframes.
importExcel function loads excel data file types(.xlsx, .xls) in a selected directory to separate dataframes, and stores them as a list. Data frames can be accessed as list elements by using "listname$filename" or "listname[]".
importExcel(path = NULL)importExcel(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single list of dataframes containing all the files imported and stored as dataframes.
importPipe function loads various text files which use a Pipe delimitter(|) in a selected directory to separate dataframes, and stores them as a list. Data frames can be accessed as list elements by using "listname$filename" or "listname[]".
importPipe(path = NULL)importPipe(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single list of dataframes containing all the files imported and stored as dataframes.
importTab function loads various text files which uses a tab delimitter in a selected directory to separate dataframes, and stores them as a list. Data frames can be accessed as list elements by using "listname$filename" or "listname[]".
importTab(path = NULL)importTab(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single list of dataframes containing all the files imported and stored as dataframes.
importTilde function loads various text files which uses a tilde delimitter(~) in a selected directory to separate dataframes, and stores them as a list. Data frames can be accessed as list elements by using "listname$filename" or "listname[]".
importTilde(path = NULL)importTilde(path = NULL)
path |
the directory in which the files are stored. If path is not given, interactive dialog box will be used to select directory |
a single list of dataframes containing all the files imported and stored as dataframes.